@@ -1,7 +1,25 @@
 import discord
 from discord.ext import commands
 from dispander import compose_embed
-from echidna.daug import get_default_embed
+from Daug.cogs.functions.embeds import compose_embed_default
+
+
+async def change_category(channel, category) -> None:
+    """チャンネルのカテゴリを変更"""
+    await channel.edit(category=category)
+
+
+async def transfer(channel_origin, guild) -> None:
+    """テキストチャンネルを指定のguildに転送"""
+    channel = await guild.create_text_channel(
+        name=channel_origin.name,
+        topic=str(channel_origin.created_at)
+    )
+    async for message in channel.history(limit=None, oldest_first=True):
+        if message.content:
+            await channel.send(embed=compose_embed(message))
+        for embed in message.embeds:
+            await channel.send(embed=embed)
 
 
 class Thread(commands.Cog):
@@ -36,10 +54,10 @@ class Thread(commands.Cog):
             category=category_open,
         )
         await channel_issue.edit(position=0)
-        await channel_issue.send(embed=get_default_embed(self.message_on_thread))
+        await channel_issue.send(embed=compose_embed_default(self.message_on_thread))
         await channel_issue.send(embed=compose_embed(message))
         await message.channel.send(
-            embed=get_default_embed(
+            embed=compose_embed_default(
                 f'スレッド {channel_issue.mention} を作成しました {message.author.mention}')
         )
         if len(message.content) <= 30:
@@ -68,6 +86,8 @@ class Thread(commands.Cog):
         return channel.category_id == self.category_open_id
 
     def is_category_closed(self, channel):
+        if channel.category is None:
+            return False
         if '✅' in channel.category.name:
             return True
         if '🚫' in channel.category.name:
@@ -89,29 +109,22 @@ class Thread(commands.Cog):
     async def dispatch_rename(self, message, rename):
         await message.channel.edit(name=rename)
         await message.channel.send(
-            embed=get_default_embed(f'チャンネル名を以下に変更しました\n{rename} ')
+            embed=compose_embed_default(f'チャンネル名を以下に変更しました\n{rename} ')
         )
 
     async def dispatch_archive(self, channel, member):
-        if self.role_contributor_id in [role.id for role in member.roles]:
-            await channel.edit(
-                category=channel.guild.get_channel(self.category_archive_id)
+        category_archive = channel.guild.get_channel(self.category_archive_id)
+        if channel.category.id == category_archive.id:
+            if not member.guild_permissions.manage_channels:
+                return
+            await transfer(
+                channel_origin=channel,
+                guild=self.bot.get_guild(self.guild_logs_id)
             )
+            await channel_origin.delete()
+        else:
+            await change_category(channel, category_archive)
             return
-        if not member.guild_permissions.administrator:
-            return
-        messages = await channel.history(limit=None).flatten()
-        guild = self.bot.get_guild(self.guild_logs_id)
-        channel = await guild.create_text_channel(
-            name=channel.name,
-            topic=str(channel.created_at)
-        )
-        for message in reversed(messages):
-            if message.content:
-                await channel.send(embed=compose_embed(message))
-            for embed in message.embeds:
-                await channel.send(embed=embed)
-        await message.channel.delete()
 
     @commands.command()
     async def name(self, ctx, *, rename):
