@@ -1,3 +1,4 @@
+from Daug.cogs.channels import Channels
 from Daug.cogs.favorite import Favorite
 from Daug.cogs.join import Join
 from Daug.cogs.leave import Leave
@@ -6,6 +7,7 @@ from Daug.cogs.utils import Utils
 
 
 def setup(bot):
+    bot.add_cog(Channels(bot))
     bot.add_cog(Thread(bot))
     bot.add_cog(Join(bot))
     bot.add_cog(Leave(bot))
